@@ -1,5 +1,5 @@
 from enum import auto
-from typing import List, Optional
+from typing import Optional
 
 from pydantic import BaseModel, Field
 
@@ -21,10 +21,9 @@ class SatelliteExtension(BaseModel):
     https://github.com/radiantearth/stac-spec/tree/v0.9.0/extensions/sat#satellite-extension-specification
     """
 
-    orbit_state: Optional[OrbitStates]
-    relative_orbit: Optional[int]
+    orbit_state: Optional[OrbitStates] = Field(None, alias="sat:orbit_state")
+    relative_orbit: Optional[int] = Field(None, alias="sat:relative_orbit")
 
     class Config:
         use_enum_values = True
         allow_population_by_field_name = True
-        alias_generator = lambda field_name: f"sat:{field_name}"
