@@ -1,7 +1,7 @@
-from enum import auto, Enum
+from enum import Enum, auto
 from typing import List, Optional, Tuple, Union
 
-from pydantic import BaseModel, Field, Extra
+from pydantic import BaseModel, Extra, Field
 
 from .utils import AutoValueEnum
 
@@ -14,6 +14,7 @@ BBox = Union[
 # https://tools.ietf.org/html/rfc3339#section-5.6
 DATETIME_RFC339 = "%Y-%m-%dT%H:%M:%SZ"
 
+
 class ExtensionTypes(str, AutoValueEnum):
     """
     https://github.com/radiantearth/stac-spec/blob/v0.9.0/extensions/README.md#list-of-content-extensions
@@ -39,6 +40,7 @@ class MimeTypes(str, Enum):
     """
     https://github.com/radiantearth/stac-spec/blob/v0.9.0/item-spec/item-spec.md#media-types
     """
+
     # Raster
     geotiff = "image/tiff; application=geotiff"
     cog = "image/geo+tiff; application=geotiff; profile=cloud-optimized"
@@ -59,6 +61,28 @@ class MimeTypes(str, Enum):
     text = "text/plain"
 
 
+class Relations(str, AutoValueEnum):
+    """
+    https://github.com/radiantearth/stac-spec/blob/v0.9.0/collection-spec/collection-spec.md#relation-types
+    """
+
+    self = auto()
+    root = auto()
+    parent = auto()
+    child = auto()
+    item = auto()
+    license = auto()
+    derived_from = auto()
+    collection = auto()
+    alternate = auto()
+    previous = auto()
+    next = auto()
+    conformance = auto()
+    docs = auto()
+    tiles = auto()
+    search = auto()
+
+
 class AssetRoles(str, AutoValueEnum):
     """
     https://github.com/radiantearth/stac-spec/blob/v0.9.0/extensions/asset/README.md
@@ -106,4 +130,4 @@ class Asset(BaseModel):
     class Config:
         allow_population_by_field_name = True
         use_enum_values = True
-        extra = Extra.allow
\ No newline at end of file
+        extra = Extra.allow
